<?php
/**
*
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2009 Jan Kulmann <jankul@zmml.uni-bremen.de>
// ATTENTION: Please send ALL bug reports and security leaks directly to the author.
//            Thx!
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+

require_once ("lib/functions.php");
require_once ("lib/messaging.inc.php");
require_once ("classes/Artikel.class.php");
require_once ("classes/Thema.class.php");
require_once ("classes/ThemaExt.class.php");
require_once ("classes/SBDBM.class.php");
require_once('vendor/flexi/template_factory.php');

class SchwarzesBrettPlugin extends AbstractStudIPSystemPlugin {

	var $zeit;
	var $template_path;
        var $factory;
	var $dbm;
	var $internal;

	function SchwarzesBrettPlugin() {
		parent::AbstractStudIPSystemPlugin();
		// Ab Stud.IP 1.8:
		/* if(!$GLOBALS['perm']->have_perm('user')){
			throw new Studip_AccessDeniedException();
		} */
		$this->internal = ($GLOBALS['auth']->auth['uid'] != 'nobody');
		$this->template_path = dirname(__FILE__) . '/templates/flexi';
                $this->factory = new Flexi_TemplateFactory($this->template_path);
		bindtextdomain('sb',dirname(__FILE__).'/locale');
		$this->zeit = get_config('BULLETIN_BOARD_DURATION') * 24 * 60 * 60;
		$this->dbm = new SBDBM($this->zeit);
		if ($this->dbm->new_items_since_last_visit())
			$this->setPluginiconname('images/header_pinn2.gif');
		else
			$this->setPluginiconname('images/header_pinn1.gif');
		// Navigationsreiter erzeugen
		$nav = new PluginNavigation();
		$nav->setDisplayname(dgettext('sb',"Schwarzes Brett"));
		$this->setNavigation($nav);
	}

	/**
	 * Setzt den Pfad zum Plugin.
	 * @param string $path Pfad zum Plugin
	 */
	function setPluginpath($path)	{
		parent::setPluginpath($path);
		$this->buildMenu();
	}

	/**
	 * Erstellt das Men des Plugins.
	 * @uses PluginNavigation
	 */
	function buildMenu() {
		$tab = new PluginNavigation();
		$tab->setDisplayname(dgettext('sb',"SchwarzesBrett"));
		$this->setNavigation( $tab );
	}

	/**
	 * Liefert den Namen des Plugins zurck.
	 * @return string Der Name des Plugins
	 */
	function getPluginname() {
		return dgettext('sb',"Schwarzes Brett Plugin");
	}

	function edit_thema_form($thema_id=FALSE) {
		$t = new Thema($thema_id);

		$template = $this->factory->open('edit_thema_form');
                $template->set_attribute('t', $t);
                $template->set_attribute('thema_id', $thema_id);
                $template->set_attribute('uri', PluginEngine::getLink($this,array()));
		$template->set_attribute('ajax_uri', PluginEngine::getURL($this,array(),'ajaxdispatch'));
                echo $template->render();
	}

	function edit_artikel_form($thema_id, $artikel_id=FALSE) {
		$a = new Artikel($artikel_id);
		if (!$artikel_id)
			$a->setThemaId($thema_id);
		$t = new Thema($thema_id);

		$subs = $this->dbm->getSubThemen($thema_id);

		$template = $this->factory->open('edit_artikel_form');
		if ($GLOBALS['perm']->have_perm('root')) {
			$themen = $this->dbm->get_themen();
			$template->set_attribute('themen', $themen);
		}
                $template->set_attribute('subs', $subs);
                $template->set_attribute('t', $t);
                $template->set_attribute('thema_id', $thema_id);
		if ($artikel_id)
	                $template->set_attribute('artikel_id', $artikel_id);
                $template->set_attribute('a', $a);
                $template->set_attribute('uri', PluginEngine::getLink($this,array()));
                $template->set_attribute('delete_tag_uri', PluginEngine::getLink($this,array("modus"=>"show_add_artikel_form","modus2"=>"delete_tag","thema_id"=>$thema_id,"artikel_id"=>$artikel_id)));
                $template->set_attribute('img_uri', $GLOBALS['ASSETS_URL']."/images/");
                $template->set_attribute('save_uri', PluginEngine::getLink($this,array("open"=>$thema_id)));
		$template->set_attribute('zeit', $this->zeit);
		$template->set_attribute('ajax_uri', PluginEngine::getURL($this,array('ajax_cmd' => 'tag_completer'),'ajaxdispatch'));
		$template->set_attribute('css_uri', $this->getPluginURL().'/styles');
                echo $template->render();
	}

	function show_artikel_body($a, $t) {
		$template = $this->factory->open('show_artikel_body');
                $template->set_attribute('a', $a);
                $template->set_attribute('avatar_uri', ($this->internal ? Avatar::getAvatar($a->getUserId())->getImageTag(Avatar::SMALL) : ""));
                $template->set_attribute('add_uri', PluginEngine::getLink($this,array("modus"=>"show_add_artikel_form", "thema_id"=>$t->getThemaId(), "artikel_id"=>$a->getArtikelId())));
                $template->set_attribute('delete_uri', PluginEngine::getLink($this,array("modus"=>"delete_artikel", "thema_id"=>$t->getThemaId(), "artikel_id"=>$a->getArtikelId())));
		$template->set_attribute('rechte', ($a->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")));
		$template->set_attribute('owner', ($a->getUserId() == $GLOBALS['auth']->auth['uid']));
		$template->set_attribute('zeit', $this->zeit);
		$template->set_attribute('search_uri', PluginEngine::getLink($this,array("modus"=>"show_search_results","search_text"=>"")));
                echo $template->render();
	}
	
	function show_tag_cloud($write = TRUE) {
		$tags = $this->dbm->getTagCounter();
		//if (count($tags) < 5) return;
		$admin_block = "";
		if ($GLOBALS['perm']->have_perm('root')) {
			$template = $this->factory->open('show_admin_block');
			$template->set_attribute('add_thema_uri', PluginEngine::getLink($this,array("modus"=>"show_add_thema_form")));
			$template->set_attribute('add_subthema_uri', PluginEngine::getLink($this,array("modus"=>"show_add_subthema_form")));
			$template->set_attribute('active_artikel', count($this->dbm->get_all_active_artikel()));
			$admin_block = $template->render();
		}
		$template = $this->factory->open('show_tag_cloud');
		$template->set_attribute('admin_block', $admin_block);
                $template->set_attribute('tags', $tags);
		$template->set_attribute('css_uri', $this->getPluginURL().'/styles');
		$template->set_attribute('search_uri', PluginEngine::getLink($this,array("modus"=>"show_search_results","search_text"=>"")));
		$template->set_attribute('search_text', $_REQUEST['search_text']);
		$template->set_attribute('ajax_uri', PluginEngine::getURL($this,array(),'ajaxdispatch'));
                $template->set_attribute('uri', PluginEngine::getLink($this,array()));
		if ($write)
	                echo $template->render();
		else
			return $template->render();
	}

	function show_shortcuts($write = TRUE) {
		$template = $this->factory->open('show_shortcuts_container');
		$template->set_attribute('image_uri', $this->getPluginURL()."/images/");
		if ($write)
	                echo $template->render();
		else
			return $template->render();
	}

	function show_artikel($a) {

		$a_open = trim($_REQUEST['a_open']);
		$t = new Thema($a->getThemaId());

		$pfeil = ($this->dbm->has_visited($a->getArtikelId()) ? "forumgrau" : "forumrot");
		$pfeil_runter = ($this->dbm->has_visited($a->getArtikelId()) ? "forumgraurunt" : "forumrotrunt");

		$options = array("zeit"=>$this->zeit, "thema_id"=>$t->getThemaId(), "lang"=>$GLOBALS['_language_path']);
		$options['general_link'] = PluginEngine::getLink($this,array());
		if ($a->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")) {
			$edit_link = PluginEngine::getLink($this,array("modus"=>"show_add_artikel_form", "thema_id"=>$t->getThemaId(), "artikel_id"=>$a->getArtikelId()));
			$delete_link = PluginEngine::getLink($this,array("modus"=>"delete_artikel", "thema_id"=>$t->getThemaId(), "artikel_id"=>$a->getArtikelId()));
			$options['edit_link'] = $edit_link;
			$options['delete_link'] = $delete_link;
		}

		$template = $this->factory->open('show_artikel');
                $template->set_attribute('t', $t);
                $template->set_attribute('o', &$this);
                $template->set_attribute('a', $a);
                $template->set_attribute('a_open', $a_open);
                $template->set_attribute('pfeil', $pfeil);
                $template->set_attribute('options', $options);
                $template->set_attribute('pfeil_runter', $pfeil_runter);
                $template->set_attribute('artikel_lookups', $this->dbm->get_artikel_lookups($a->getArtikelId()));
                $template->set_attribute('artikel_uri', PluginEngine::getLink($this,array("a_open"=>($a_open==$a->getArtikelId()?"":$a->getArtikelId()))));
                $template->set_attribute('img_uri', $this->getPluginURL()."/images");
                echo $template->render();
	}

	function print_js_opener() {
		$template = $this->factory->open('js_opener');
                $template->set_attribute('plugin_uri', $this->getPluginURL());
                $template->set_attribute('img_uri', $GLOBALS['ASSETS_URL']."/images/");
                $template->set_attribute('image_uri', $this->getPluginURL()."/images/");
		$template->set_attribute('ajax_uri', PluginEngine::getURL($this,array(),'ajaxdispatch'));
                echo $template->render();
	}

	function list_artikel($thema_id) {
		$a_open = trim($_REQUEST['a_open']);
		$t = new Thema($thema_id);
		$subs = $this->dbm->getSubThemen($thema_id);
		$artikel = $this->dbm->get_artikel($thema_id);
		if (count($artikel) == 0)
			echo "<DIV STYLE=\"font-size:0.8em; font-style:italic; margin-bottom:10px; padding-left:5px;\">".dgettext('sb',"Zur Zeit sind keine Anzeigen vorhanden")."</DIV>\n";
		else {
			if (count($subs)) {
				foreach ($subs as $s) {
					$sartikel = $this->dbm->get_artikel($thema_id, $s['subthema_id']);
					if (count($sartikel)) {
						echo "<DIV STYLE=\"clear:both;\"></DIV><DIV STYLE=\"color:green; font-size:12px; font-style:bold; padding-left:0px; padding-top:5px; padding:bottom:5px; border-bottom:1px solid gray;\">".htmlReady($s['titel'])." [".count($sartikel)."]<DIV STYLE=\"float:right;\"><IMG ID=\"s_".$s['subthema_id']."\" onClick=\"toggleSubThema('s_".$s['subthema_id']."');\" SRC=\"".$this->getPluginURL()."/images/pfeilgrau_up.gif\" ALT=\"Zuklappen\" TITLE=\"Zuklappen\"></DIV></DIV>\n";
						echo "<DIV ID=\"ds_".$s['subthema_id']."\">\n";
						foreach ($sartikel as $a) {
							$this->show_artikel($a);
						}
						echo "</DIV>\n";
					}
				}
			}
			echo "<DIV STYLE=\"clear:both;\"></DIV><DIV STYLE=\"color:green; font-size:12px; font-style:bold; padding-left:0px; padding-top:5px; padding:bottom:3px; border-bottom:1px solid gray;\">Unsortiert [".count($artikel)."]<DIV STYLE=\"float:right;\"><IMG ID=\"s_".$thema_id."\" onClick=\"toggleSubThema('s_".$thema_id."');\" SRC=\"".$this->getPluginURL()."/images/pfeilgrau_up.gif\" ALT=\"Zuklappen\" TITLE=\"Zuklappen\"></DIV></DIV>\n";
			echo "<DIV ID=\"ds_".$thema_id."\">\n";
			foreach ($artikel as $a) {
				$this->show_artikel($a);
			}
			echo "</DIV>\n";
		}
		if ($GLOBALS['perm']->have_perm($t->getPerm()))
			echo "<DIV STYLE=\"clear:both;\"></DIV><DIV STYLE=\"margin-top:10px; text-align:center;\"><A STYLE=\"font-size:11px;\" HREF=\"".PluginEngine::getLink($this,array("modus"=>"show_add_artikel_form", "thema_id"=>$thema_id))."\">".dgettext('sb',"Neue Anzeige anlegen")."</A></DIV>\n";

	}

	function list_themen() {
		$counter = 0;
		$this->print_js_opener();
		$themen = $this->dbm->get_themen();

		if (count($themen) > 3) {
			$tmp_count = array(0=>0, 1=>0, 2=>0);
			$tmp_themen = array(0=>array(), 1=>array(), 2=>array());
			foreach ($themen as $tt) {
				$anzahl = $tt->getArtikelCount();
				$anzahl = ($anzahl == 0 ? 1 : $anzahl);
				foreach ($tmp_count as $c_key=>$c_val){
					$tmp_count[$c_key] += $anzahl;
					array_push($tmp_themen[$c_key], $tt);
					break;
				}
				asort($tmp_count,SORT_NUMERIC);
			}
			asort($tmp_count,SORT_NUMERIC);
		}

		$template = $this->factory->open('list_themen');
                $template->set_attribute('delete_thema_uri', PluginEngine::getLink($this,array("modus"=>"delete_thema")));
                $template->set_attribute('add_thema_uri', PluginEngine::getLink($this,array("modus"=>"show_add_thema_form")));
                $template->set_attribute('img_uri', $this->getPluginURL()."/images");
                $template->set_attribute('rss_uri', $this->getPluginURL().'/rss.php');
                $template->set_attribute('themen', $themen);
                $template->set_attribute('o', &$this);
                $template->set_attribute('tmp_themen', $tmp_themen);
                $template->set_attribute('rechte', $GLOBALS['perm']->have_perm("root"));
                echo $template->render();
	}

	function do_search($search_text) {
		$articles = $this->dbm->search_query($search_text);
		$thema_id = "";
		$this->print_js_opener();
		$template = $this->factory->open('header');
		$template->set_attribute('shortcuts', '&nbsp;');
		$template->set_attribute('cloud', $this->show_tag_cloud(FALSE));
		echo $template->render();
		//$this->show_tag_cloud();

		$template = $this->factory->open('show_search_results');
                $template->set_attribute('articles', $articles);
                $template->set_attribute('thema_id', $thema_id);
		$template->set_attribute('img_uri', $this->getPluginURL()."/images/");
                $template->set_attribute('o', &$this);
                echo $template->render();
	}

	function parse_msg($txt) {
		echo "<TABLE BORDER=\"0\">\n";
		parse_msg($txt);
		echo "</TABLE>\n";
	}

	function show() {
		//$GLOBALS['perm']->check('autor');
		$db = new DB_Seminar();
		$open = trim($_REQUEST['open']);
		$modus = trim($_REQUEST['modus']);
		$modus2 = trim($_REQUEST['modus2']);
		$artikel_id = trim($_REQUEST['artikel_id']);
		$thema_id = trim($_REQUEST['thema_id']);
		$a_open = trim($_REQUEST['a_open']);

		if ($this->internal) {
			$this->dbm->visit("root","thema");
			if ($a_open) $this->dbm->visit($a_open,"artikel");
		}

		//include_once 'templates/header.tpl';

		if ($GLOBALS['perm']->have_perm("root")) {
			$this->dbm->garbageCollect();
		}

		if ($modus) {
			if ($this->internal) { // sind wir eingeloggt oder doch nur externer?
				if ($GLOBALS['perm']->have_perm("root")) {
					if ($modus == "move2thema" && $artikel_id) {
						$t = new Thema($_REQUEST['move_thema_id']);
						$a = new Artikel($artikel_id);
						$a->setThemaId($t->getThemaId());
						$a->save();
						if ($a->getUserId() != $GLOBALS['auth']->auth['uid']) {
                                                        $messaging=new messaging;
                                                        $msg = sprintf(dgettext('sb',"Die Anzeige \"%s\" wurde von der Administration in das Thema \"%s\" verschoben."),$a->getTitel(), $t->getTitel());
                                                        $messaging->insert_message($msg, get_username($a->getUserId()), "____%system%____", FALSE, FALSE, 1, FALSE, dgettext('sb',"Anzeige verschoben."));
                                                }
						$this->parse_msg("msg".dgettext('sb',"Artikel wurde verschoben."));
						unset($modus);
					}
					if ($modus == "save_thema") {
						$t = new Thema($thema_id);
						$t->setTitel($_REQUEST['titel']);
						$t->setBeschreibung($_REQUEST['beschreibung']);
						$t->setPerm($_REQUEST['sb_perm']);
						$t->setVisible(($_REQUEST['visible'] ? 1 : 0));
						$t->save();
						$this->parse_msg("msg".dgettext('sb',"Thema wurde gespeichert."));
						unset($modus);
					}
					if ($modus == "show_add_thema_form")
						$this->edit_thema_form($thema_id);
					if ($modus == "delete_thema") {
						$t = new Thema($thema_id);
						$yes = "<A HREF=\"".PluginEngine::getLink($this,array("modus"=>"delete_thema_really", "thema_id"=>$t->getThemaId()))."\">".makeButton("ja","img")."</A>";
						$no = "<A HREF=\"".PluginEngine::getLink($this,array())."\">".makeButton("nein","img")."</A>";
						$this->parse_msg(sprintf("info".dgettext('sb',"Soll das Thema \"%s\" wirklich gel&ouml;scht werden?<BR>%s %s"),$t->getTitel(), $yes, $no));
						unset($modus);
					}
					if ($modus == "delete_thema_really") {
						$t = new Thema($thema_id);
						$t->delete();
						$this->parse_msg("msg".dgettext('sb',"Thema wurde gel&ouml;scht."));
						unset($modus);
					}
				}
				if ($modus == "add_artikel" && $GLOBALS['perm']->have_perm($this->dbm->get_thema_perm($open))) {
					$a = new Artikel($artikel_id);
					if (trim($_REQUEST['titel']) != "") {
						if (!($this->dbm->is_duplicate($_REQUEST['titel']) && !$artikel_id) || ($artikel_id && ($a->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")))) {
							$a->setTitel($_REQUEST['titel']);
							$a->setBeschreibung($_REQUEST['beschreibung']);
							$a->setThemaId($open);
							$a->setVisible(($_REQUEST['visible'] ? 1 : 0));
							$a->setPublicVisible(($_REQUEST['public_visible'] ? 1 : 0));
							$a->setSubThemaId($_REQUEST['sub_id']);
							$a->save();
							$a->setTags(trim($_REQUEST['tags']));
							$this->parse_msg("msg".dgettext('sb',"Anzeige wurde gespeichert."));
						}
					}
					unset($a);
					unset($modus);
				}
				if ($modus == "show_add_artikel_form") {
					if ($modus2 == "delete_tag") {
						$a = new Artikel($artikel_id);
						if ($a->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")) {
							$a->removeTag(trim($_REQUEST['tag']));
						}
						unset($a);
					}
					$this->edit_artikel_form($thema_id, $artikel_id);
				}
				if ($modus == "delete_artikel") {
					$a = new Artikel($artikel_id);
					if ($a->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")) {
						$autor_name = "<A HREF=\"about.php?username=".get_username($a->getUserId())."\">".htmlReady(get_fullname($a->getUserId()))."</A>";
						$yes = "<A HREF=\"".PluginEngine::getLink($this,array("modus"=>"delete_artikel_really", "artikel_id"=>$a->getArtikelId()))."\">".makeButton("ja","img")."</A>";
						$no = "<A HREF=\"".PluginEngine::getLink($this,array())."\">".makeButton("nein","img")."</A>";
						$this->parse_msg(sprintf("info".dgettext('sb',"Soll die Anzeige \"%s\" von %s wirklich gel&ouml;scht werden?<BR>%s %s"),$a->getTitel(), $autor_name, $yes, $no));
					}
					unset($modus);
				}
				if ($modus == "delete_artikel_really") {
					$a = new Artikel($artikel_id);
					if ($a->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")) {
						if ($a->getUserId() != $GLOBALS['auth']->auth['uid'] && $GLOBALS['perm']->have_perm("root")) {
							$messaging=new messaging;
							$msg = sprintf(dgettext('sb',"Die Anzeige \"%s\" wurde von der Administration geloescht."),$a->getTitel());
							$messaging->insert_message($msg, get_username($a->getUserId()), "____%system%____", FALSE, FALSE, 1, FALSE, dgettext('sb',"Anzeige geloescht!"));
						}
						$this->parse_msg("msg".dgettext('sb',"Anzeige gel&ouml;scht!"));
						$a->delete();
					}
					unset($modus);
				}
			} // internal
			if ($modus == "show_search_results") {
				$txt = trim($_REQUEST['search_text']);
				if ($txt && strlen($txt) > 2) 
					$this->do_search($txt);
				else {
					$this->parse_msg("error".dgettext('sb',"Bitte geben Sie mehr als zwei Zeichen ein!"));
					unset($modus);
				}
			}
		}
		if (!$modus) {
			$slogans = $this->dbm->getSlogans();
			$template = $this->factory->open('header');
			$template->set_attribute('shortcuts', $this->show_shortcuts(FALSE));
			$template->set_attribute('cloud', $this->show_tag_cloud(FALSE));
			if (count($slogans) > 0) {
				$idx = rand(0, count($slogans) - 1);
				$template_slogan = $this->factory->open('slogan');
				$template_slogan->set_attribute('img_uri', $this->getPluginURL()."/images/");
				$template_slogan->set_attribute('ajax_uri', PluginEngine::getURL($this,array(),'ajaxdispatch'));
				$template_slogan->set_attribute('slogan_body', stripslashes($slogans[$idx]['body']));
				$template_slogan->set_attribute('slogan_author', stripslashes($slogans[$idx]['author']));
				$template->set_attribute('slogan', $template_slogan->render());
			}			
			echo $template->render();
			$this->list_themen();
		}
		
	}

	// Ab Stud.IP 1.8...
	function actionAjaxDispatch(){
		ob_end_clean();
		if (!array_key_exists('ajax_cmd', $_REQUEST)) die;
		switch($_REQUEST['ajax_cmd']) {
		case 'visitObj':
			$obj_id = trim($_REQUEST['objid']);
			if (!$obj_id) break;
			$this->dbm->visit($obj_id, "artikel");
			echo "success";
			break;
		case 'getContent':
			$obj_id = trim($_REQUEST['objid']);
			if (!$obj_id) break;
			$this->dbm->visit($obj_id, "artikel");
			$a = new Artikel($obj_id);
			$options = unserialize(base64_decode($_REQUEST['options']));
			if (!$GLOBALS['_language_path']) $GLOBALS['_language_path'] = $options['lang'];
			$template = $this->factory->open('show_artikel_body');
	                $template->set_attribute('a', $a);
			$template->set_attribute('plugin', &$this);
        	        $template->set_attribute('zeit', $this->zeit);
                	$template->set_attribute('search_uri', $options['general_link']."?modus=show_search_results&search_text=");
	                $template->set_attribute('avatar_uri', ($this->internal ? Avatar::getAvatar($a->getUserId())->getImageTag(Avatar::SMALL) : ""));
        	        $template->set_attribute('add_uri', $options['edit_link']);
                	$template->set_attribute('delete_uri', $options['delete_link']);
	                $template->set_attribute('rechte', ($a->getUserId() == $GLOBALS['auth']->auth['uid'] || $GLOBALS['perm']->have_perm("root")));
        	        $template->set_attribute('owner', ($a->getUserId() == $GLOBALS['auth']->auth['uid']));
                	echo $template->render();
			break;
		case 'tag_completer':
	                $val = (basename(trim($_REQUEST['value'])));
        	        if ($val == "") return;
                	echo SBDBM::searchForTags($val);
	                break;
		case 'create_subthema':
			if (!$GLOBALS['perm']->have_perm("root")) die();
			$val = trim((basename(utf8_decode($_REQUEST['sub_value']))));
			$tid = trim((basename(utf8_decode($_REQUEST['thema_id']))));
			if ($val && $tid) {
				$this->dbm->insertSubThema($val, $tid);
			}
			echo "Neues Unterthema erstellen";
			break;
		case 'update_subthema':
			if (!$GLOBALS['perm']->have_perm("root")) die();
			$val = trim((basename(utf8_decode($_REQUEST['sub_value']))));
			$tid = trim((basename(utf8_decode($_REQUEST['thema_id']))));
			$sid = trim((basename(utf8_decode($_REQUEST['sub_id']))));
			if ($tid && $sid) {
				$this->dbm->updateSubThema($val, $tid, $sid);
			}
			echo $val;
			break;
		case 'get_sub_themen':
			$tid = trim((basename(utf8_decode($_REQUEST['thema_id']))));
			$subs = $this->dbm->getSubThemen($tid);
			if (count($subs)) {
				$out = "";
				foreach ($subs as $s) {
					$template = $this->factory->open('subthema_item');
					$template->set_attribute('ajax_uri', PluginEngine::getURL($this,array(),'ajaxdispatch'));
					$template->set_attribute('thema_id', $tid);
					$template->set_attribute('s', $s);
					$out .= $template->render();
				}
				echo $out;
			} else echo "<SPAN STYLE=\"font-size:10;\">Zur Zeit sind keine Unterthemen definiert.</SPAN>";
			break;
		case 'getNewContentShortcuts':
			$items = $this->dbm->new_items_since_last_visit_sorted();
			$themen = $this->dbm->get_themen_sorted();
			$template = $this->factory->open('show_shortcuts');
	                $template->set_attribute('themen', $themen);
			$template->set_attribute('items', $items);
                	echo $template->render();
			break;
		case 'create_slogan':
			if (!$GLOBALS['perm']->have_perm("root")) die();
			$s_body = trim(utf8_decode($_REQUEST['slogan_body']));
			$s_author = trim(utf8_decode($_REQUEST['slogan_author']));
			if ($s_body) {
				$this->dbm->insertSlogan($s_body, $s_author);
			}
			break;
	
		default: ;
		}
		die();
	}

	function actionShow() {
		return $this->show();
	}

}

?>
